Matte's Dada
===

Semi-random text generator using Markov chains

[![Build Status](https://travis-ci.org/mattesilver/dada.svg?branch=master)](https://travis-ci.org/mattesilver/dada)
![PyPI](https://img.shields.io/pypi/v/mattes-dada.svg?style=plastic)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mattes-dada.svg?style=plastic)
[![codecov](https://codecov.io/gh/mattesilver/dada/branch/master/graph/badge.svg)](https://codecov.io/gh/mattesilver/dada)

Usage
==

```shell
mdada input_file
```

where input_file is a path to either a txt ot odt file.

Example output:

```
the emancipation proclamation, the phrase goes, thirty, when, as the principal insurgent army, could not whether they ask the white, the new louisiana
now, and means of constituency, reached, and yet been my duty to some supposed to my own opinion whether these, the arms of louisiana, a national constitution, whenever i shall treat with it
if we, as before stated
we say this i abstain from any professed emancipationist, adopted a new state, and each state government for him, civil and inflexible plan
i shall sooner by sustaining it
```